(ACR) Apply comments
authorsung.goo.kim <sung.goo.kim@samsung.com>
Fri, 6 Nov 2015 08:44:05 +0000 (17:44 +0900)
committerYoungjae Shin <yj99.shin@samsung.com>
Tue, 10 Nov 2015 10:13:23 +0000 (19:13 +0900)
Change-Id: Icfef2800626b486e06f4d7bd0d1718482a940b6f

lib/icl-dbus.h
lib/icl.c
lib/include/iotcon-client.h
lib/include/iotcon-remote-resource.h
lib/include/iotcon.h

index f46f32e..e8fdd62 100644 (file)
@@ -18,7 +18,7 @@
 
 #include "ic-dbus.h"
 
-#define ICL_DBUS_TIMEOUT_DEFAULT 10 /* 10 sec */
+#define ICL_DBUS_TIMEOUT_DEFAULT 30 /* 30 sec */
 #define ICL_DBUS_TIMEOUT_MAX 60 /* 60 sec */
 
 
index 33c2c50..aec808d 100644 (file)
--- a/lib/icl.c
+++ b/lib/icl.c
@@ -55,7 +55,7 @@ API int iotcon_set_timeout(int timeout_seconds)
        int ret;
 
        if (ICL_DBUS_TIMEOUT_MAX < timeout_seconds || timeout_seconds <= 0) {
-               ERR("Invalid seconds (%d)", timeout_seconds);
+               ERR("timeout_seconds(%d) must be in range from 1 to 60", timeout_seconds);
                return IOTCON_ERROR_INVALID_PARAMETER;
        }
 
index 0bd8157..b12a692 100644 (file)
@@ -41,6 +41,7 @@
 /**
  * @brief Specifies the type of function passed to iotcon_add_presence_cb().
  * @details Called when client receive presence events from the server.
+ * The @a response handle contains about presence information.
  *
  * @since_tizen 3.0
  *
  * @pre The callback must be registered using iotcon_add_presence_cb()
  *
  * @see iotcon_add_presence_cb()
+ * @see iotcon_remove_presence_cb()
+ * @see iotcon_presence_response_get_connectivity_type()
+ * @see iotcon_presence_response_get_host_address()
+ * @see iotcon_presence_response_get_resource_type()
+ * @see iotcon_presence_response_get_result()
+ * @see iotcon_presence_response_get_trigger()
  */
 typedef void (*iotcon_presence_cb)(iotcon_presence_h presence, iotcon_error_e err,
                iotcon_presence_response_h response, void *user_data);
@@ -59,7 +66,7 @@ typedef void (*iotcon_presence_cb)(iotcon_presence_h presence, iotcon_error_e er
 /**
  * @brief Adds callback to a server to receive presence events.
  * @details Request to receive presence to an interested server's resource with @a resource_type.\n
- * If succeed to subscribe, iotcon_presence_cb() will be invoked when the server sends presence\n
+ * If succeed to subscribe, iotcon_presence_cb() will be invoked when the server sends presence.\n
  * A server sends presence events when adds/removes/alters a resource or start/stop presence.
  *
  * @since_tizen 3.0
@@ -207,10 +214,11 @@ int iotcon_presence_response_get_result(iotcon_presence_response_h response, int
  * @brief Gets trigger from the presence response handle
  *
  * @details The @a trigger could be one of #iotcon_presence_trigger_e.
+ * It is set only if a response result is IOTCON_PRESENCE_OK.
  * @since_tizen 3.0
  *
  * @param[in] response The handle of the presence response
- * @param[out] trigger The presence trigger value. It is set only if @a result is IOTCON_PRESENCE_OK.
+ * @param[out] trigger The presence trigger value.
  *
  * @return 0 on success, otherwise a negative error value.
  * @retval #IOTCON_ERROR_NONE  Successful
index 8ac2245..c102408 100644 (file)
@@ -115,10 +115,11 @@ int iotcon_remote_resource_clone(iotcon_remote_resource_h src, iotcon_remote_res
 
 
 /**
- * @brief Specifies the type of function passed to iotcon_remote_resource_start_observing(),
+ * @brief Specifies the type of response function.
+ * @details The function passed to iotcon_remote_resource_start_observing(),
  * iotcon_remote_resource_get(), iotcon_remote_resource_put(), iotcon_remote_resource_post(),
  * iotcon_remote_resource_delete().
- * @details The @a err could be one of #iotcon_error_e.
+ * The @a err could be one of #iotcon_error_e.
  * The @a request_type could be one of #iotcon_request_type_e.
  *
  * @since_tizen 3.0
index 4a93622..6985fd5 100644 (file)
@@ -75,7 +75,8 @@ int iotcon_connect(void);
 void iotcon_disconnect(void);
 
 /**
- * @brief Gets the timeout seconds of iotcon_get_device_info(),
+ * @brief Gets the timeout seconds of asynchronous API.
+ * @details This API get the timeout of iotcon_get_device_info(),
  * iotcon_get_platform_info(), iotcon_get_tizen_info(), iotcon_find_resource(),
  * iotcon_remote_resource_get(), iotcon_remote_resource_put(),
  * iotcon_remote_resource_post() and iotcon_remote_resource_delete().
@@ -95,16 +96,16 @@ void iotcon_disconnect(void);
 int iotcon_get_timeout(int *timeout_seconds);
 
 /**
- * @brief Sets the timeout seconds of iotcon_get_device_info(),
+ * @brief Sets the timeout seconds of asynchrous APIs.
+ * @details This API set the timeout of iotcon_get_device_info(),
  * iotcon_get_platform_info(), iotcon_get_tizen_info(), iotcon_find_resource(),
  * iotcon_remote_resource_get(), iotcon_remote_resource_put(),
- * iotcon_remote_resource_post() and iotcon_remote_resource_delete().
- * @details Default timeout interval is 10 seconds.
- * Maximum timeout interval is 60 seconds.
+ * iotcon_remote_resource_post() and iotcon_remote_resource_delete().\n
+ * Default timeout interval value is 30.
  *
  * @since_tizen 3.0
  *
* @param[in] timeout_seconds Seconds for timeout
  *
  * @return 0 on success, otherwise a negative error value.
  * @retval #IOTCON_ERROR_NONE Successful
@@ -95,16 +96,16 @@ void iotcon_disconnect(void);
  * @since_tizen 3.0
  *
- * @param[in] timeout_seconds Seconds for timeout
+ * @param[in] timeout_seconds Seconds for timeout (must be in range from 1 to 60)
  *
  * @return 0 on success, otherwise a negative error value.